@@ -1,4 +1,4 @@
-#2422 --
+# --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
 # Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # Copyright (C) 2021 maxence business consulting GmbH, http://www.maxence.de
@@ -440,9 +440,10 @@ sub Run {
 
     # check basic needed permissions
     my $Access = $Self->CheckAccessPermissions(
-        TicketID => $TicketID,
-        UserID   => $PermissionUserID,
-        UserType => $UserType,
+        TicketID       => $TicketID,
+        UserID         => $PermissionUserID,
+        UserType       => $UserType,
+        PermissionType => 'rw',
     );
 
     if ( !$Access ) {
