@@ -559,7 +559,7 @@ to delete a file from file system
         Directory       => 'c:\some\location',
         Filename        => 'me_to/alal.xml',
         # or Location
-        Location        => 'c:\some\location\me_to\alal.xml'
+        Location        => 'c:\some\location\me_to\alal.xml',
 
         Type            => 'Local',   # optional - Local|Attachment|MD5
         DisableWarnings => 1, # optional
