@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -273,8 +273,8 @@ Returns:
 
     my %ConfigItemParams = (
         ConfigItemID  => 1,
-        DeplStateName => 'Production'
-        InciStateName => 'Operational'
+        DeplStateName => 'Production',
+        InciStateName => 'Operational',
         XMLData => {
             'CPU' => [
                 {
