@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -659,6 +659,9 @@ sub _GetCustomFileList {
             # do not include documentation
             next FILE if $File =~ /doc/;
 
+            # do not include sessions
+            next FILE if $File =~ /sessions/;
+
             # add directory to list
             push @Files, $Self->_GetCustomFileList( Directory => $File );
         }
