@@ -1,6 +1,6 @@
 // --
 // Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-// Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+// Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -131,7 +131,10 @@ Core.App = (function (TargetNS) {
             });
             return AppropriateBrowser;
         }
-        alert(Core.Language.Translate('Error: Browser Check failed!'));
+        Core.UI.Dialog.ShowAlert(
+            Core.Language.Translate('An Error Occurred'),
+            Core.Language.Translate('Error: Browser Check failed!')
+        );
     };
 
     /**
