@@ -1,6 +1,6 @@
 // --
 // Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-// Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+// Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -19,12 +19,13 @@ Core.UI.Popup = (function (Namespace) {
 
         QUnit.test('PopupProfiles', function(Assert){
 
+            var ProfileList = Core.UI.Popup.ProfileList();
             var ExpectedProfiles = {
                 'Default': {
                     WindowURLParams: "dependent=yes,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,toolbar=no",
                     Left: 100,
                     Top: 100,
-                    Width: 1040,
+                    Width: ProfileList.Default.Width || 1040,
                     Height: 700
                 }
             };
